% ode02B.m
%
% Numerically integrate a 1D ODE (exponential growth) using the
% Runge-Kutta 45 solver
%
% Growth equation:
% dx/dt = a * x 
%     a = free parameter (units = 1/time)
%     x = # monkeys
%
% This code calls the user-definied function ode02_derivs.m, which must
% be in the same folder as this program
%
% Versions:
%     This version (ode02B.m) compares the numerical Runge-Kutta 4-5
%     solution with the analytic solution and graphs the error between
%     them.

close all
clear
clc

%%%%%%%%%%   Initialize Parameters   %%%%%%%%%%

tBegin = 0;     % time begin
tEnd = 10;      % time end

x0 = 10;        % initial position (10 initial monkeys)

global a;       % declare as global so logistic_derivs() can access it
a = 0.3;        % set value of the free parameter


%%%%%%%%%%  Use the Runge-Kutta 45 solver to solve the ODE  %%%%%%%%%%

% set integration tolerances
options = odeset('RelTol', 1e-8, 'AbsTol', 1e-8);
[t,x] = ode45(@ode02_derivs, [tBegin tEnd], x0, options);


% Calculate exact solution
x_exact = x0 * exp(a * t);


%%%%%%%%%%  Plot Results   %%%%%%%%%%

%%%%% Top Plot - x(t)
subplot(2,1,1)
plot(t,x,'bo');            % plot ode45 solution as blue circles
hold on
plot(t,x_exact,'r-')       % plot analytic solution as a solid red line

title('Exponential Growth');            % title
xlabel('time');                         % label x axis
ylabel('Monkey Population');            % label y axis
legend('rk45', 'analytic', 'Location', 'Northwest')     % legend top left


%%%%  Lower Plot - error(t)
subplot(2,1,2)
plot(t,x-x_exact,'b-');     % plot ode45 solution as blue circles connected by lines

xlabel('time');                         % label x axis
ylabel('Error');                        % label y axis


%%%%%%%%%%  Save plot as .pdf  %%%%%%%%%%

h = 8;                                  % height of plot in inches
w = 6;                                  % width of plot in inches
set(gcf, 'PaperSize', [w h]);           % set size of PDF page
set(gcf, 'PaperPosition', [0 0 w h]);   % put plot in lower-left corner
print ('-dpdf','ode02C.pdf');           % save plot as pdf file