% ode04A.m
%
% Numerically integrate a 1D ODE (gravitational acceleration with turbulent
% air drag) using the Runge-Kutta 45 solver. 
%
% Equation of Motion:
%    ma = - mg - C_d v |v|
%     m = free parameter 
%   C_d = drag force coefficient
%
% This code calls the user-definied function air_drag_1D_derivs.m, which must
% be in the same folder as this code
%

close all
clear
clc

%%%%%%%%%%   Initialize Parameters   %%%%%%%%%%

tBegin = 0;     % time begin
tEnd   = 2;     % time end

x0 = 0;         % initial position (m)
v0 = 15;        % initial velocity (m/s)

% define global variables used in derivative function
global m;       % mass (kg)
global C_d;     % turbulent drag coef. Drag force = DC * v^2

m   = 1; 
C_d = 0.3;


%%%%%%%%%%  Use the Runge-Kutta 45 solver to solve the ODE  %%%%%%%%%%

[t,w] = ode45(@ode04_derivs, [tBegin tEnd], [x0 v0]);   

x = w(:,1);     % extract positions from first column of w matrix
v = w(:,2);     % extract velocities from second column of w matrix


%%%%%%%%%%  Plot Results   %%%%%%%%%%

% top plot - x(t)
subplot(2,1,1)
plot(t,x);

title('Projectile Motion with Air Drag');
ylabel('position (m)');
xlabel('time (s)');


% bottom plot - v(t)
subplot(2,1,2)
plot(t,v);

ylabel('velocity (m/s)');
xlabel('time (s)');


%%%%%  Save to file
h = 8;                                  % height of plot in inches
w = 6;                                  % width of plot in inches
set(gcf, 'PaperSize', [w h]);           % set size of PDF page
set(gcf, 'PaperPosition', [0 0 w h]);   % put plot in lower-left corner
print ('-dpdf','ode04A.pdf');           % save plot as pdf file


