% ode04B.m
%
% Numerically integrate a 1D ODE (gravitational acceleration with turbulent
% air drag) using the Runge-Kutta 45 solver. 
%
% Equation of Motion:
%    ma = - mg - C_d v |v|
%     m = free parameter 
%   C_d = drag force coefficient
%
% This code calls the user-definied function air_drag_1D_derivs.m, which must
% be in the same folder as this code
%
% Version History:
%   ode04B - This version runs 4 simulations with different drag
%   coefficients. It creates two plots:  x(t) and v(t). An array of plot
%   styles is used so that the the model run in each plot has the same
%   style and color.

close all
clear
clc

%%%%%%%%%%   Initialize Parameters   %%%%%%%%%%

tBegin = 0;     % time begin
tEnd   = 2.2;     % time end

x0 = 0;         % initial position (m)
v0  = 10;       % initial velocity (m/s)

% define global variables used in derivative function
global m;       % mass (kg)
global C_d;     % turbulent drag coef. Drag force = DC * v^2

m   = 1; 
C_d_list = [0 0.1 0.3 1];          % drag coefs for three different runs
                                   % this is an array of values so square 
                                   % brackets [] are used
                                   
color = {'r-', 'm-', 'b-', 'k-'};  % plot styles for each model run. 
                                   % this is a list of strings, so curly
                                   % brackets {} are used
    

%%%%%%%%%%  Loop through each plot drag coefficient  %%%%%%%%%
for k = 1:length(C_d_list)
    
    % assign the global variable C_d (used in the  function air_drag_1D_derivs) 
    % to the kth value in the C_d_array
    C_d = C_d_list(k);
    
    % set events for ODE solver - this will terminate the integration when
    % the projectile crosses x = 0
    options = odeset('Events',@ODE04C_events);

    % Use the Runge-Kutta 45 solver to solve the ODE
    [t,w] = ode45(@ode04_derivs, [tBegin tEnd], [x0 v0], options);   

    x = w(:,1);     % extract positions from first column of w matrix
    v = w(:,2);     % extract velocities from second column of w matrix

    %%%%%%%%%%  Plot Results   %%%%%%%%%%

    % top subplot graphs x vs t
    % notice the plot type is given by the kth element of the color{} list
    subplot(2,1,1)
    plot(t,x, color{k});
    hold on

    % lower subplot graphs v vs t
    % notice the plot type is given by the kth element of the color{} list
    subplot(2,1,2)
    plot(t,v, color{k});
    hold on
end


%%%%%%%%%%  Plot Results   %%%%%%%%%%

% title, labels, legend for top subplot
subplot(2,1,1)
title('Projectile Motion with Air Drag');
ylabel('position (m)');
xlabel('time (s)');
legend('C_d = 0', 'C_d = 0.1', 'C_d = 0.3', 'C_d = 1.0')
ylim([0 6])

% title, labels, legend for lower subplot
subplot(2,1,2)
ylabel('velocity (m/s)');
xlabel('time (s)');
legend('C_d = 0', 'C_d = 0.1', 'C_d = 0.3', 'C_d = 1.0')


%%%%%  Save to file
h = 10;                                  % height of plot in inches
w = 6;                                  % width of plot in inches
set(gcf, 'PaperSize', [w h]);           % set size of PDF page
set(gcf, 'PaperPosition', [0 0 w h]);   % put plot in lower-left corner
print ('-dpdf','ode04C.pdf');           % save plot as pdf file


